=========
OZI.build
=========

This is the OZI fork of the mesonpep517 0.2 tag.

This is a simple module that implements pep517 for the meson build system.

This means that you only need to provide a ``pyproject.toml`` in your project
source root to be able to publish your project built with meson on PyPI
and to create a wheel for the project.

For more information have a look at _`the documentation <https://thiblahute.gitlab.io/mesonpep517/>`

See Also:

https://mesonbuild.com